YARP 2.3.20 (2012-11-23)                                              {#v2_3_20}
========================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.3.19...v2.3.20`):

```
   148	Daniele E. Domenichelli <daniele.domenichelli@iit.it>
    74	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    31	Lorenzo Natale <lorenzo.natale@iit.it>
    10	Ugo Pattacini <ugo.pattacini@iit.it>
     7	Alessandro Scalzo <alessandro.scalzo@iit.it>
     7	Elena Ceseracciu <elena.ceseracciu@iit.it>
     6	Marco Randazzo <marco.randazzo@iit.it>
     4	Ali Paikan <ali.paikan@iit.it>
     4	Francesco Nori <francesco.nori@iit.it>
     2	Duarte Aragao <daragao@gmail.com>
     1	Alberto Cardellino <alberto.cardellino@iit.it>
     1	Fabien Benureau <fabien.benureau@gmail.com>
     1	Vadim Tikhanoff <vadim.tikhanoff@iit.it>
```
